@@ -56,7 +56,7 @@ class UserData(BaseModel):
     id: str
     name: str  # "alice"
     password: str  # "secret"
-    ucsschoolRole: List[str]  # ["student"] or ["teacher"]
+    ucsschoolRole: List[str]  # ["student"], ["teacher"] or ["legal_guardian"]
     pseudonyms: Dict[str, str]  # {"idBrokerPseudonym0001": "012-345"}
 
 
